"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
Object.defineProperty(exports, "__esModule", { value: true });
const codegen_1 = require("@microsoft.azure/codegen");
const expression_1 = require("./expression");
const method_1 = require("./method");
class Constructor extends method_1.Method {
    constructor(containingClass, objectIntializer) {
        super(containingClass.name);
        this.containingClass = containingClass;
        this.apply(objectIntializer);
    }
    get declaration() {
        const parameterDeclaration = this.parameters.joinWith(p => p.declaration, codegen_1.CommaChar);
        return `
${this.summaryDocumentation}
${this.parameterDocumentation}
${this.access} ${this.static} ${this.abstract} ${this.name}(${parameterDeclaration})
`.slim();
    }
    invoke(...parameters) {
        return expression_1.toExpression(`new ${this.containingClass.name}(${parameters.joinWith(each => expression_1.valueOf(each))})`);
    }
}
exports.Constructor = Constructor;
//# sourceMappingURL=constructor.js.map