import { Dictionary } from '@microsoft.azure/codegen';
import { Expression, ExpressionOrLiteral, LiteralExpression } from './expression';
import { Namespace } from './namespace';
import { Parameter } from './parameter';
import { Property } from './property';
import { TypeDeclaration } from './type-declaration';
import { Variable } from './variable';
export declare class ClassType implements TypeDeclaration {
    private name;
    private readonly fullName;
    private namespace;
    constructor(namespace: Namespace | string, name: string);
    readonly declaration: string;
    toString(): string;
    new(...parameters: Array<ExpressionOrLiteral>): Expression;
    Cast(expression: ExpressionOrLiteral): Expression;
}
export declare class EnumType implements TypeDeclaration {
    private namespace;
    private name;
    constructor(namespace: Namespace, name: string);
    readonly declaration: string;
    member(enumMember: string): Expression;
    readonly definition: string;
    toString(): string;
    newProperty(name: string, objectInitializer?: Partial<Property>): Property;
    newParameter(name: string, objectInitializer?: Partial<Parameter>): Parameter;
    withMembers<T>(): T & EnumType;
}
export interface Index<T> {
    [key: number]: T;
}
export declare const None: Namespace;
export declare const System: Namespace & {
    Threading: Namespace & {
        CancellationToken: ClassType;
        CancellationTokenSource: ClassType;
        Tasks: Namespace & {
            Task(taskType?: TypeDeclaration | undefined): TypeDeclaration;
        };
    };
    Object: ClassType;
    String: ClassType & {
        Empty: LiteralExpression;
        IsNullOrEmpty: (expression: ExpressionOrLiteral) => Expression;
        IsNullOrWhitespace: (expression: ExpressionOrLiteral) => Expression;
        /** @description Binds a Variable to the known instance methods of this type */
        $BindTo: ($instance: Variable) => Variable & {
            Substring: (start: ExpressionOrLiteral, end?: string | Expression | undefined) => string;
        };
    };
    DateTime: ClassType;
    EventArgs: ClassType;
    Exception: ClassType;
    AggregateException: ClassType;
    TimeSpan: ClassType;
    Type: ClassType;
    Uri: ClassType;
    IFormatProvider: ClassType;
    Xml: Namespace & {
        Linq: Namespace & {
            XElement: ClassType;
            XAttribute: ClassType;
        };
    };
    IO: Namespace & {
        Stream: ClassType;
    };
    Text: Namespace & {
        Encoding: ClassType & {
            UTF8: LiteralExpression;
        };
    };
    Net: Namespace & {
        WebProxy: ClassType;
        Http: Namespace & {
            HttpRequestMessage: ClassType;
            HttpClient: ClassType;
            HttpClientHandler: ClassType;
            HttpResponseMessage: ClassType;
            Headers: Namespace & {
                HttpHeaders: ClassType;
                HttpResponseHeaders: ClassType;
            };
            StringContent: ClassType;
            StreamContent: ClassType;
            MultipartFormDataContent: ClassType;
        };
        HttpStatusCode: ClassType & Dictionary<LiteralExpression> & Index<LiteralExpression>;
    };
    Collections: Namespace & {
        Hashtable: ClassType;
        Generic: Namespace & {
            Dictionary(keyType: TypeDeclaration, valueType: TypeDeclaration): TypeDeclaration;
            KeyValuePair(keyType: TypeDeclaration, valueType: TypeDeclaration): TypeDeclaration;
            IEnumerable(type: TypeDeclaration): TypeDeclaration;
        };
    };
    Action(...actionParameters: TypeDeclaration[]): TypeDeclaration;
    Func(...funcParameters: TypeDeclaration[]): TypeDeclaration;
};
export declare const dotnet: {
    Unknown: ClassType;
    ToDo: ClassType;
    Void: ClassType;
    String: ClassType;
    Int: ClassType;
    Long: ClassType;
    Double: ClassType;
    Float: ClassType;
    Binary: ClassType;
    Bool: ClassType;
    Object: ClassType;
    Dynamic: ClassType;
    ThisObject: ClassType;
    Var: ClassType;
    True: LiteralExpression;
    False: LiteralExpression;
    Null: LiteralExpression;
    This: LiteralExpression;
};
//# sourceMappingURL=dotnet.d.ts.map