import { Async } from './access-modifier';
import { Parameter } from './parameter';
import { OneOrMoreStatements, Statements } from './statements/statement';
import { TypeDeclaration } from './type-declaration';
import { LocalVariable } from './variable';
export declare type ExpressionOrLiteral = Expression | string;
export declare function toExpression(expression: ExpressionOrLiteral): Expression;
export declare function valueOf(expression: ExpressionOrLiteral): string;
/** An expression is a combination of operands (variables, literals, method calls) and operators that can be evaluated to a single value  */
export interface Expression {
    value: string;
    IsNull: Expression;
    IsNotNull: Expression;
    toString(): string;
    Cast(toType: TypeDeclaration): Expression;
}
export declare abstract class BaseExpression implements Expression {
    abstract value: string;
    toString(): string;
    readonly IsNull: Expression;
    readonly IsNotNull: Expression;
    Cast(toType: TypeDeclaration): Expression;
}
/** an expression of a constant string value  */
export declare class StringExpression extends BaseExpression {
    value: string;
    constructor(value: string);
}
/** an arbitrary user-defined expression  */
export declare class LiteralExpression extends BaseExpression {
    value: string;
    constructor(value: string);
}
/** a c# 'is' expression */
export declare function Is(expression: ExpressionOrLiteral, isType: TypeDeclaration): Expression;
/** a c# 'is' expression */
export declare class IsExpression extends BaseExpression {
    expression: ExpressionOrLiteral;
    isType: TypeDeclaration;
    constructor(expression: ExpressionOrLiteral, isType: TypeDeclaration);
    readonly value: string;
}
/** a c# 'is' expression that declares a local variable  */
export declare function IsDeclaration(expression: ExpressionOrLiteral, isType: TypeDeclaration, name: string): IsExpressionDeclaration;
/** a c# 'is' expression that declares a local variable  */
export declare class IsExpressionDeclaration extends LocalVariable implements Expression {
    expression: ExpressionOrLiteral;
    isType: TypeDeclaration;
    constructor(expression: ExpressionOrLiteral, isType: TypeDeclaration, name: string);
    readonly check: Expression;
    readonly IsNull: Expression;
    readonly IsNotNull: Expression;
    Cast(toType: TypeDeclaration): Expression;
    readonly value: string;
    toString(): string;
}
export declare function Lambda(parameters: Array<Parameter>, body: OneOrMoreStatements, objectIntializer?: Partial<LambdaExpression>): void;
export declare class LambdaExpression extends Statements implements Expression {
    protected parameters: Array<Parameter>;
    protected body: OneOrMoreStatements;
    async: Async;
    constructor(parameters: Array<Parameter>, body: OneOrMoreStatements, objectIntializer?: Partial<LambdaExpression>);
    readonly value: string;
    toString(): string;
    readonly IsNull: Expression;
    Cast(toType: TypeDeclaration): Expression;
    readonly IsNotNull: Expression;
}
//# sourceMappingURL=expression.d.ts.map