"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
Object.defineProperty(exports, "__esModule", { value: true });
function Import(namespace) {
    return new ImportDirective(namespace);
}
exports.Import = Import;
function ImportStatic(namespace) {
    return new ImportStaticDirective(namespace.declaration);
}
exports.ImportStatic = ImportStatic;
class ImportDirective {
    constructor(namespaceOrType) {
        this.namespaceOrType = namespaceOrType;
    }
    get implementation() {
        return `using ${this.namespaceOrType};`;
    }
}
exports.ImportDirective = ImportDirective;
class ImportStaticDirective extends ImportDirective {
    constructor(namespace) {
        super(namespace);
    }
    get implementation() {
        return `using static ${this.namespaceOrType};`;
    }
}
exports.ImportStaticDirective = ImportStaticDirective;
/** An Alias adds a using statement to a namespace, and can then be used as a type declaration too. */
class Alias extends ImportDirective {
    constructor(aliasName, typeDeclaration) {
        super(`${aliasName} = ${typeDeclaration.declaration}`);
        this.aliasName = aliasName;
        this.typeDeclaration = typeDeclaration;
    }
    get fullDefinition() {
        return this.typeDeclaration;
    }
    get declaration() {
        return this.aliasName;
    }
}
exports.Alias = Alias;
//# sourceMappingURL=import.js.map