"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
Object.defineProperty(exports, "__esModule", { value: true });
const codegen_1 = require("@microsoft.azure/codegen");
const expression_1 = require("../expression");
const statement_1 = require("./statement");
function If(conditional, statements, objectInitializer) {
    return new IfStatement(conditional, statements, objectInitializer);
}
exports.If = If;
class IfStatement extends statement_1.Statements {
    constructor(conditional, statements, objectInitializer) {
        super(statements);
        this.conditional = conditional;
        this.apply(objectInitializer);
    }
    get implementation() {
        return `
if (${expression_1.valueOf(this.conditional)})
{
${codegen_1.indent(super.implementation)}
}`.trim();
    }
}
exports.IfStatement = IfStatement;
function While(conditional, statements, objectInitializer) {
    return new WhileStatement(conditional, statements, objectInitializer);
}
exports.While = While;
class WhileStatement extends statement_1.Statements {
    constructor(conditional, statements, objectInitializer) {
        super(statements);
        this.conditional = expression_1.toExpression(conditional);
        this.apply(objectInitializer);
    }
    get implementation() {
        return `
while (${this.conditional.value})
{
${codegen_1.indent(super.implementation)}
}`.trim();
    }
}
exports.WhileStatement = WhileStatement;
class ElseIfStatement extends statement_1.Statements {
    constructor(conditional, statements, objectInitializer) {
        super(statements);
        this.conditional = expression_1.toExpression(conditional);
        this.apply(objectInitializer);
    }
    get implementation() {
        return `
else if (${this.conditional.value})
{
${codegen_1.indent(super.implementation)}
}`.trim();
    }
}
exports.ElseIfStatement = ElseIfStatement;
function ElseIf(conditional, statements, objectInitializer) {
    return new ElseIfStatement(conditional, statements, objectInitializer);
}
exports.ElseIf = ElseIf;
function Else(statements, objectInitializer) {
    return new ElseStatement(statements, objectInitializer);
}
exports.Else = Else;
class ElseStatement extends statement_1.Statements {
    constructor(statements, objectInitializer) {
        super(statements);
        this.apply(objectInitializer);
    }
    get implementation() {
        return `
else
{
${codegen_1.indent(super.implementation)}
}`.trim();
    }
}
exports.ElseStatement = ElseStatement;
function Not(conditional) {
    return new expression_1.LiteralExpression(`!(${conditional.value})`);
}
exports.Not = Not;
//# sourceMappingURL=if.js.map